======================================
Python API for Exoscale's DNS offering
======================================


.. image:: https://img.shields.io/pypi/v/exoscale_dns.svg
        :target: https://pypi.python.org/pypi/exoscale_dns

.. image:: https://img.shields.io/travis/digitalmensch/exoscale_dns.svg
        :target: https://travis-ci.org/digitalmensch/exoscale_dns

.. image:: https://readthedocs.org/projects/exoscale-dns/badge/?version=latest
        :target: https://exoscale-dns.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/digitalmensch/exoscale_dns/shield.svg
     :target: https://pyup.io/repos/github/digitalmensch/exoscale_dns/
     :alt: Updates



Python API for Exoscale's DNS offering


* Free software: MIT license
* Documentation: https://exoscale-dns.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
